@@ -1,7 +1,6 @@
 # coding: utf-8
 from __future__ import unicode_literals
 
-
 import re
 import json
 
@@ -42,12 +41,12 @@ class HelixmediaIE(InfoExtractor):
         launch_webpage = self._download_webpage(launch_url, video_id, 'Downloading helixmedia launch webpage')
         launch_inputs = self._form_hidden_inputs(self._LAUNCH_FORM, launch_webpage)
         launch_form_str = self._search_regex(
-            r'(?P<form><form[^>]+?id=(["\'])%s\2[^>]*>)' % self._LAUNCH_FORM, launch_webpage, 'login form', group='form'
+            fr'(?P<form><form[^>]+?id=(["\']){self._LAUNCH_FORM}\2[^>]*>)', launch_webpage, 'login form', group='form'
         )
 
         action_url = extract_attributes(launch_form_str).get('action')
 
-        submit_page, start_urlh = self._download_webpage_handle(
+        dummy, start_urlh = self._download_webpage_handle(
             action_url, video_id, 'Launch helixmedia app', data=urlencode_postdata(launch_inputs)
         )
 
